Ricardo Heers / X_NUCLEO_IKS01A1

Dependencies:   X_NUCLEO_COMMON X_NUCLEO_IKS01A1 ST_INTERFACES

Revision:
30:7b36639ee80a
Parent:
28:501726e9220d
Child:
32:2bb1d4ced32b
diff -r 501726e9220d -r 7b36639ee80a Components/Common/MagneticSensor.h
--- a/Components/Common/MagneticSensor.h	Thu Jun 04 11:51:44 2015 +0200
+++ b/Components/Common/MagneticSensor.h	Thu Jun 04 13:46:35 2015 +0200
@@ -51,41 +51,41 @@
  public:
 	/**
 	 * @brief       Initialization of magnetometer
 	 * @param[out]  Pointer to device specific initalization structure
 	 * @retval      0 in case of success, an error code otherwise
 	 */
-	virtual int Init(void*) = 0;
+	virtual int Init(void *ptr) = 0;
 	
 	/**
 	 * @brief       Get ID of magnetometer
-	 * @param[out]  Pointer to where to store the ID to
+	 * @param[out]  id Pointer to where to store the ID to
 	 * @retval      0 in case of success, an error code otherwise
 	 */
-	virtual int ReadID(uint8_t*) = 0;
+	virtual int ReadID(uint8_t *id) = 0;
 
 	/**
 	 * @brief       Get current magnetometer magnetic X/Y/Z-axes values 
 	 *              in standard data units [mgauss]
 	 * @param[out]  Pointer to where to store magnetic values to.
 	 *              Pointer must point to an array of (at least) three elements, where:
 	 *              ptr[0] corresponds to X-axis
 	 *              ptr[1] corresponds to Y-axis
 	 *              ptr[2] corresponds to Z-axis
 	 * @retval      0 in case of success, an error code otherwise
 	 */
-	virtual int Get_M_Axes(int32_t*) = 0;
+	virtual int Get_M_Axes(int32_t *pData) = 0;
 
 	/**
 	 * @brief       Get current magnetometer raw data X/Y/Z-axes values 
 	 *              in device sepcific LSB units
 	 * @param[out]  Pointer to where to store magnetometer raw data to.
 	 *              Pointer must point to an array of (at least) three elements, where:
 	 *              ptr[0] corresponds to X-axis
 	 *              ptr[1] corresponds to Y-axis
 	 *              ptr[2] corresponds to Z-axis
 	 * @retval      0 in case of success, an error code otherwise
 	 */
-	virtual int Get_M_AxesRaw(int16_t *) = 0;
+	virtual int Get_M_AxesRaw(int16_t *pData) = 0;
 };
 
 #endif /* __MAGNETIC_SENSOR_CLASS_H */
@@ -51,41 +51,41 @@
 	/**
 	 * @brief       Initialization of magnetometer
-	 * @param[out]  Pointer to device specific initalization structure
+	 * @param[out]  ptr Pointer to device specific initalization structure
 	 * @retval      0 in case of success, an error code otherwise
 	 */
@@ -51,41 +51,41 @@
 	 * @brief       Get current magnetometer magnetic X/Y/Z-axes values 
 	 *              in standard data units [mgauss]
-	 * @param[out]  Pointer to where to store magnetic values to.
-	 *              Pointer must point to an array of (at least) three elements, where:
-	 *              ptr[0] corresponds to X-axis
-	 *              ptr[1] corresponds to Y-axis
-	 *              ptr[2] corresponds to Z-axis
+	 * @param[out]  pData Pointer to where to store magnetic values to.
+	 *              pData must point to an array of (at least) three elements, where:
+	 *              pData[0] corresponds to X-axis,
+	 *              pData[1] corresponds to Y-axis, and
+	 *              pData[2] corresponds to Z-axis.
 	 * @retval      0 in case of success, an error code otherwise
 	 */
@@ -51,41 +51,41 @@
 	 * @brief       Get current magnetometer raw data X/Y/Z-axes values 
 	 *              in device sepcific LSB units
-	 * @param[out]  Pointer to where to store magnetometer raw data to.
-	 *              Pointer must point to an array of (at least) three elements, where:
-	 *              ptr[0] corresponds to X-axis
-	 *              ptr[1] corresponds to Y-axis
-	 *              ptr[2] corresponds to Z-axis
+	 * @param[out]  pData Pointer to where to store magnetometer raw data to.
+	 *              pData must point to an array of (at least) three elements, where:
+	 *              pData[0] corresponds to X-axis,
+	 *              pData[1] corresponds to Y-axis, and
+	 *              pData[2] corresponds to Z-axis.
 	 * @retval      0 in case of success, an error code otherwise
 	 */